summaryrefslogtreecommitdiffstats
path: root/sound/usb/line6/midi.c
diff options
context:
space:
mode:
authorChris Rorvick2015-01-20 09:20:49 +0100
committerTakashi Iwai2015-01-20 09:52:30 +0100
commitc6fffce92e1a8cda8c1b552f5a24295839f3f93a (patch)
treebd550e912d3cea8916757d8e65e946a33515a0e1 /sound/usb/line6/midi.c
parentALSA: line6: Remove superfluous NULL checks (diff)
downloadkernel-qcow2-linux-c6fffce92e1a8cda8c1b552f5a24295839f3f93a.tar.gz
kernel-qcow2-linux-c6fffce92e1a8cda8c1b552f5a24295839f3f93a.tar.xz
kernel-qcow2-linux-c6fffce92e1a8cda8c1b552f5a24295839f3f93a.zip
ALSA: line6: Refer to manufacturer as "Line 6"
The correct spelling includes the space. Fix this in strings and comments that refer to the manufacturer. Signed-off-by: Chris Rorvick <chris@rorvick.com> Signed-off-by: Takashi Iwai <tiwai@suse.de>
Diffstat (limited to 'sound/usb/line6/midi.c')
-rw-r--r--sound/usb/line6/midi.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/sound/usb/line6/midi.c b/sound/usb/line6/midi.c
index 68793cc5dc1e..64e242b9ce82 100644
--- a/sound/usb/line6/midi.c
+++ b/sound/usb/line6/midi.c
@@ -1,5 +1,5 @@
/*
* Line6 Linux USB driver - 0.9.1beta
*
* Copyright (C) 2004-2010 Markus Grabner (grabner@icg.tugraz.at)
*
@@ -226,7 +226,7 @@ static int snd_line6_new_midi(struct usb_line6 *line6,
struct snd_rawmidi *rmidi;
int err;
- err = snd_rawmidi_new(line6->card, "Line6 MIDI", 0, 1, 1, rmidi_ret);
+ err = snd_rawmidi_new(line6->card, "Line 6 MIDI", 0, 1, 1, rmidi_ret);
if (err < 0)
return err;
@@ -256,7 +256,7 @@ static void snd_line6_midi_free(struct snd_rawmidi *rmidi)
}
/*
- Initialize the Line6 MIDI subsystem.
+ Initialize the Line 6 MIDI subsystem.
*/
int line6_init_midi(struct usb_line6 *line6)
{
@@ -1,5 +1,5 @@
/*
- * Line6 Linux USB driver - 0.9.1beta
+ * Line 6 Linux USB driver - 0.9.1beta
*
* Copyright (C) 2004-2010 Markus Grabner (grabner@icg.tugraz.at)